# Changelog

## v1.0.0 (2023-06-07)

#### Performance improvements

* make a deep copy of 'paths' before popping in find_dupes
* speed up execution by only comparing files of the same size
#### Refactorings

* rename sort_by_size to group_by_size
* change function names
#### Docs

* update readme
#### Others

* add function import statements


## v0.2.1 (2023-06-01)

#### Fixes

* fix issues during file deletion

## v0.2.0 (2023-05-31)

#### New Features

* add cli option for excluding files
* cli can accept a list of paths to compare files from

## v0.1.0 (2023-05-30)

#### Performance improvements

* enhance readability of delete_wizard()
#### Docs

* correct a few typos in pyproject.toml


